@@ -214,17 +214,22 @@ class SICard():
     @classmethod
     def from_auto_send(cls, data: bytes, station: 'SiUSBStation'):
         """create a SI Card object from the data send with auto send."""
-        control_number = bytes_to_int(data[:2])
-        si_number = cls.decode_number(data[2:6])
-        time = cls.decode_time(data[7:10], data[6])
+        data_new = [x for x in data]
+        if data_new[2] == 0x0f:
+            #measures for working with SRR
+            data_new[0] = data[0] & 0x7f
+            data_new[2] = 0x0
+        control_number = bytes_to_int(data_new[:2])
+        si_number = cls.decode_number(data_new[2:6])
+        time = cls.decode_time(data_new[7:10], data[6])
         # mem_pointer = bytes_to_int(data[10:])
         card: SICard
         if si_number <= 499999:
-            card = SI5(data[2:6], station)
+            card = SI5(data_new[2:6], station)
         elif 500000 <= si_number <= 999999 or (2003000 <= si_number <= 2003999):
-            card = SI6(data[2:6], station)
+            card = SI6(data_new[2:6], station)
         else:
-            card = SI8To10.switch_types(data[2:6], station)
+            card = SI8To10.switch_types(data_new[2:6], station)
         card.add_punch(Punch(control_number, time))
         return card
 
@@ -235,7 +240,7 @@ class SICard():
         self._punches.append(punch)
 
     @classmethod
-    def decode_time(cls, raw_time: bytes, punchdate: int = None, reftime: 'datetime' = None) -> 'Optional[datetime]':
+    def decode_time(cls, raw_time: 'Union[bytes, List[int]]', punchdate: int = None, reftime: 'datetime' = None) -> 'Optional[datetime]':
         """decode date and time from bytes before reftime"""
         if raw_time == cls.TIME_RESET:
             return None
@@ -306,7 +311,7 @@ class SI5(SICard):
     PTH = 0x1
     PTL = 0x2
 
-    def __init__(self, data: bytes, station: 'SiUSBStation' = None):
+    def __init__(self, data: 'Union[bytes, List[int]]', station: 'SiUSBStation' = None):
         self._number = self.decode_number(data)
         if station:
             self._station = station
@@ -391,7 +396,7 @@ class SI6(SICard):
 
     SI6_STAR = b'\x01\x01\x01\x02'
 
-    def __init__(self, data: bytes, station: 'SiUSBStation' = None):
+    def __init__(self, data: 'Union[bytes, List[int]]', station: 'SiUSBStation' = None):
         self._number = bytes_to_int(data)
         if station:
             self._station = station
@@ -448,14 +453,14 @@ class SI8To10(SICard):
     """meta class for all SICard 8 and up"""
     _data_name_list: 'Tuple[str, ...]' = ("first_name", "last_name")
 
-    def __init__(self, data: bytes, station: 'SiUSBStation' = None):
+    def __init__(self, data: 'Union[bytes, List[int]]', station: 'SiUSBStation' = None):
         self._number = bytes_to_int(data[1:])
         if station:
             self._station = station
         self._read_at = datetime.now()
 
     @classmethod
-    def switch_types(cls, data: bytes, station: 'SiUSBStation' = None) -> 'SI8To10':
+    def switch_types(cls, data: 'Union[bytes, List[int]]', station: 'SiUSBStation' = None) -> 'SI8To10':
         """switch between the SI Card Types 8 and up, via their number range"""
         num = bytes_to_int(data[1:])
         if 2000000 <= num <= 2999999:
