@@ -180,10 +180,11 @@ mode_rev: Dict[int, str] = {
 class siacmode(IntEnum): # pylint: disable=invalid-name
     """enum for different SIAC radio modes"""
     NO_SIAC=0x00
+    SIAC_SPECIAL=0x10
     NO_RADIO=0x30
     LAST_RECORD=0x70
     ALL_RECORDS=0xb0
-    UNSET_RECORDS=0xf0
+    UNSENT_RECORDS=0xf0
 
 siacmode_rev: Dict[int, str] = {
     v.value: k for k, v in siacmode.__members__.items()}
