@@ -12,7 +12,8 @@ from sipyconfig.card import SI5, SI6, SI8To10, SICard
 from sipyconfig.comms import ACK, NOACK, Command, receive_command, send_command
 from sipyconfig.enums import (CPC, SETTINGS, SiCardInserted, SiCardRemoved,
                               SiError, com, memaddr, memlen, misc, mode_rev,
-                              proto, stationmode)
+                              proto, stationmode, SiCardAutoSend, siacmode,
+                              siacmode_rev, MODELID, model_rev)
 from sipyconfig.utils import (apply_bit_mask, array_or, bytes_to_int, is_siac_mode,
                               is_siac_special_mode, log2)
 
@@ -30,6 +31,9 @@ class SiUSBStation():
     _extended_protocol: bool = True
     _direct_mode: Optional[bool] = None
 
+    _model_id: MODELID = MODELID.UNKNOWN
+    _model_id_str: str = "UNKNOWN"
+
     _mem_size: int = -1
     _sys_data: List[int]
 
@@ -50,6 +54,8 @@ class SiUSBStation():
     _control_number: int = -1
     _mode: stationmode = stationmode.UNKNOWN
     _mode_str: str = "UNKNOWN"
+    _siac_mode: siacmode = siacmode.NO_SIAC
+    _siac_mode_str: str = "NO_SIAC"
 
     _si_card: Optional[SICard] = None
     _time: 'datetime'
@@ -137,13 +143,19 @@ class SiUSBStation():
                 cn1, cn0 = ret.data[0], ret.data[1]
                 self._control_number = (cn1 << 8) + cn0
 
-                self._mode = stationmode(self._sys_data[memaddr.MODE])
+                self._model_id = MODELID(bytes(self._sys_data[memaddr.MODEL_ID:memaddr.MODEL_ID+memlen.MODEL_ID]))
+                self._model_id_str = model_rev.get(self._model_id.value, "UNKNOWN")
+
+                self._mode = stationmode(self._sys_data[memaddr.MODE] & 0x3f)
                 if self._mode == stationmode.SIAC_SPECIAL:
                     self._control_number = self._sys_data[memaddr.CONTROL_NUMBER]
                     self._mode_str = mode_rev.get(self._control_number, "UNKNOWN")
                 else:
                     self._mode_str = mode_rev.get(self._mode, "UNKNOWN")
 
+                self._siac_mode = siacmode(self._sys_data[memaddr.MODE] & 0xf0)
+                self._siac_mode_str = siacmode_rev.get(self._siac_mode, "NO_SIAC")
+
                 self._setting = self._sys_data[memaddr.SETTINGS_FLAG]
                 self._optical_feedback = bool(self._setting & SETTINGS.OPTICAL_FEEDBACK)
                 self._acoustic_feedback = bool(self._setting & SETTINGS.ACOUSTIC_FEEDBACK)
@@ -232,17 +244,26 @@ class SiUSBStation():
         elif is_siac_special_mode(mode):
             sys_copy = self._splice_control_number(sys_copy, mode)
             mode = stationmode.SIAC_SPECIAL
+        if not is_siac_mode(mode):
+            self._siac_mode = siacmode.NO_SIAC
         sys_copy[memaddr.SIAC] = misc.SIAC_ON if is_siac_mode(mode) else misc.SIAC_OFF
-        sys_copy[memaddr.MODE] = mode
+        sys_copy[memaddr.MODE] = mode | self.siac_mode
         self.send_command(com.SET_SYS_DATA, [int(memaddr.SIAC)] + sys_copy[memaddr.SIAC:memaddr.SETTINGS_FLAG+1], True)
         self.get_system_info()
 
+    def set_siac_mode(self, siac_mode: siacmode) -> None:
+        """set SIAC SRR behaviour (only for SIAC_CONTROL, SIAC_START, SIAC_FINISH)"""
+        if not is_siac_mode(self.mode):
+            raise SiError("Can't set SIAC SRR behaviour for current mode!")
+        self.send_command(com.SET_SYS_DATA, [int(memaddr.MODE), self.mode | siac_mode], True)
+        self.get_system_info()
+
     def set_protocol_setting(self, setting: CPC, set_val: bool):
         """set a single setting of the protocol settings byte"""
-        sett = apply_bit_mask(self._cpc, setting, set_val)
+        sett = apply_bit_mask(self._cpc, setting, set_val << (log2(setting) - 1))
         if setting in [CPC.AUTO_SEND, CPC.HANDSHAKE]:
             setting = CPC.AUTO_SEND if setting == CPC.HANDSHAKE else CPC.HANDSHAKE
-            sett = apply_bit_mask(sett, setting, set_val)
+            sett = apply_bit_mask(sett, setting, int(not set_val) << (log2(setting) - 1))
         self.send_command(com.SET_SYS_DATA, [memaddr.PROTOCOL_MODE_FLAG, sett], True)
 
     def set_protocol_settings(self, settings: List[CPC], values: List[int]) -> None:
@@ -269,14 +290,27 @@ class SiUSBStation():
 
     def trigger_feedback(self, num: int = 1) -> bool:
         """Trigger acoustic and/or visual feedback of the station <num> times"""
-        self.send_command(com.FEEDBACK, [num])
-        return not isinstance(self.receive_command(), NOACK)
+        if self.model_id != MODELID.SIMSSR1_AP:
+            return not isinstance(self.send_command(com.FEEDBACK, [num]), NOACK)
+        else:
+            return True
 
     def ensure_readout(self) -> None:
         """ensures that the station is set to direct mode and is in mode READOUT"""
         self.flush()
         self.set_mode_direct(True)
         self.set_mode(stationmode.READOUT)
+        self.set_protocol_setting(CPC.AUTO_SEND, False)
+        self.get_system_info()
+
+    def ensure_control_readout(self, control_number: int = None, enable_siac: bool = False):
+        """ensures that the station is configured to receive SI Punches in Control Mode"""
+        self.set_mode_direct(True)
+        self.set_mode(stationmode.SIAC_CONTROL if enable_siac else stationmode.CONTROL)
+        if control_number is not None:
+            self.set_control_number(control_number)
+        self.set_protocol_setting(CPC.AUTO_SEND, True)
+        self.get_system_info()
 
     def wait_for_si_card(self, timeout: float = None, *, no_ack: bool = False) -> Optional[SICard]:
         """waits for an SiCard to be inserted, waits a maximum of timeout (infinite if unset),
@@ -295,6 +329,8 @@ class SiUSBStation():
                 return self._si_card
             except SiCardRemoved:
                 pass
+            except SiCardAutoSend:
+                return self._si_card
             finally:
                 self._currently_waiting = False
             if timeout is not None and time.time() - invoke_time >= timeout:
@@ -340,6 +376,9 @@ class SiUSBStation():
                 raise SiCardInserted("SI-Card insert during command.")
             elif ret.command_code == com.SI_REMOVED:
                 raise SiCardRemoved("SI-Card removed during command.")
+            elif ret.command_code == com.PUNCH_DATA:
+                self._si_card = SICard.from_auto_send(ret.data, self)
+                raise SiCardAutoSend("SI-Card insert with auto send enabled.")
         return ret
 
     def flush(self, flush_input: bool = True, flush_output: bool = True):
@@ -388,7 +427,7 @@ class SiUSBStation():
 
     @property
     def auto_send(self) -> Optional[bool]:
-        """whether autosend for readout is enabled, currently this is not supported"""
+        """whether autosend for readout is enabled, currently this is only supported for control read out"""
         return getattr(self, "_auto_send", None)
 
     @auto_send.setter
@@ -397,7 +436,7 @@ class SiUSBStation():
 
     @property
     def handshake(self) -> Optional[bool]:
-        """whether handshake mode for readout is enabled, currently this is the only mode supported"""
+        """whether handshake mode for readout is enabled, currently this is the only mode supported for full SICard read out"""
         return getattr(self, "_handshake", None)
 
     @handshake.setter
@@ -463,11 +502,35 @@ class SiUSBStation():
     def mode(self, mode: stationmode) -> None:
         self.set_mode(mode)
 
+    @property
+    def siac_mode(self) -> siacmode:
+        """current SIAC SRR behaviour"""
+        return self._siac_mode
+
+    @siac_mode.setter
+    def siac_mode(self, siac_mode: siacmode) -> None:
+        self.set_siac_mode(siac_mode)
+
+    @property
+    def model_id(self) -> MODELID:
+        """bytes of model id"""
+        return self._model_id
+
+    @property
+    def model_id_string(self) -> str:
+        """string name of model id"""
+        return self._model_id_str
+
     @property
     def mode_string(self) -> str:
         """string name of the current operating mode"""
         return self._mode_str
 
+    @property
+    def siac_mode_string(self) -> str:
+        """string name of the current SIAC SRR behaviour"""
+        return self._siac_mode_str
+
     @property
     def time(self) -> Optional[datetime]:
         """current time of the station, calculated with the read out time and the timedelta since the readout"""
