@@ -87,7 +87,7 @@ class ReadOutWidget(QScrollArea):
 
 class MainWindow(QMainWindow):
 
-    def __init__(self) -> None:
+    def __init__(self, device: str = None) -> None:
         super().__init__()
 
         self.setWindowTitle("SPORTident Py-Config")
@@ -97,7 +97,7 @@ class MainWindow(QMainWindow):
             pass
 
         self.initUI()
-        self.initSerial()
+        self.initSerial(device)
 
     def initUI(self):
         self.main_wid = QTabWidget()
@@ -218,8 +218,8 @@ class MainWindow(QMainWindow):
 
         self.main_wid.addTab(self.debug_wid, "Debug")
 
-    def initSerial(self):
-        self.si = SiUSBStation()
+    def initSerial(self, device: str = None):
+        self.si = SiUSBStation(device)
         self.si.max_command_tries = 10
 
         self.read_out_thread.setStation(self.si)
@@ -348,9 +348,9 @@ if __name__ == "__main__":
     environ["QT_SCREEN_SCALE_FACTORS"] = "1"
     environ["QT_SCALE_FACTOR"] = "1"
 
-    app = QApplication(sys.argv)
+    app = QApplication([])
 
-    window = MainWindow()
+    window = MainWindow(sys.argv[1] if len(sys.argv) > 1 else None)
     window.show()
 
     sys.exit(app.exec_())
